==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_mediastore_data/paginator.py <==
"""
Type annotations for mediastore-data service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mediastore_data.client import MediaStoreDataClient
    from types_boto3_mediastore_data.paginator import (
        ListItemsPaginator,
    )

    session = Session()
    client: MediaStoreDataClient = session.client("mediastore-data")

    list_items_paginator: ListItemsPaginator = client.get_paginator("list_items")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListItemsRequestListItemsPaginateTypeDef, ListItemsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListItemsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListItemsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListItemsRequestListItemsPaginateTypeDef]
    ) -> _PageIterator[ListItemsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_mediastore_data/paginator.py <==
"""
Type annotations for mediastore-data service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mediastore_data.client import MediaStoreDataClient
    from types_boto3_mediastore_data.paginator import (
        ListItemsPaginator,
    )

    session = Session()
    client: MediaStoreDataClient = session.client("mediastore-data")

    list_items_paginator: ListItemsPaginator = client.get_paginator("list_items")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListItemsRequestPaginateTypeDef, ListItemsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListItemsPaginator",)


if TYPE_CHECKING:
    _ListItemsPaginatorBase = Paginator[ListItemsResponseTypeDef]
else:
    _ListItemsPaginatorBase = Paginator  # type: ignore[assignment]


class ListItemsPaginator(_ListItemsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListItemsRequestPaginateTypeDef]
    ) -> PageIterator[ListItemsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
        """
